BaseClient class abstract

Implementers

Constructors

BaseClient({required String token, String version = latestVersion, String dateVersion = latestDateVersion})

Properties

dateVersion ↔ String
The API date version.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
path ↔ String
The path of the requests group.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
token ↔ String
The API integration secret token.
getter/setter pair
v ↔ String
The API version.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited