ToDo class

A representation of the Paragraph Notion block object.

Inheritance

Constructors

ToDo({Text? text, List<Text> texts = const [], List<Block> children = const [], bool checked = false, @deprecated String textSeparator = ' '})
Main to do constructor.

Properties

checked ↔ bool
The checked value.
getter/setter pair
children → List<Block>
The children of this block.
no setter
content → List<Text>
The content of this block.
no setter
createdTime ↔ String
The creation time of the object.
getter/setter pairinherited
hasChildren ↔ bool
The checker for block children.
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
The block id.
getter/setter pairinherited
isBulletedItem → bool
Returns true if is a Bulleted block.
no setterinherited
isChild → bool
Returns true if is a Child block.
no setterinherited
isHeading → bool
Returns true if is a Heading block.
no setterinherited
isNone → bool
Returns true if is none block.
no setterinherited
isNumberedItem → bool
Returns true if is a Numbered block.
no setterinherited
isParagraph → bool
Returns true if is a Paragraph block.
no setterinherited
isToDo → bool
Returns true if is a ToDo block.
no setterinherited
isToogle → bool
Returns true if is a Toogle block.
no setterinherited
jsonContent ↔ Map<String, dynamic>
The json representation for the content of the block.
getter/setter pairinherited
lastEditedTime ↔ String
The last edited time of the object.
getter/setter pairinherited
object ↔ ObjectTypes
The type of object. Always Block for this.
finalgetter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
strObject → String
The string value for this object type.
no setterinherited
strType → String
The string value for this block type.
no setterinherited
textSeparator ↔ String
The separator for the Text objects.
getter/setter pair
type ↔ BlockTypes
The block type. Always ToDo for this.
finalgetter/setter pairinherited-setteroverride-getter

Methods

add(Text text) → ToDo
Add a new text to the paragraph content and returns this instance.
addChild(Block block) → ToDo
Add a new block to the children and returns this instance.
addChildren(List<Block> blocks) → ToDo
Add a list of blocks to the children and returns this instance.
addText(String text, {TextAnnotations? annotations}) → ToDo
Add a text to the rich text array and returns this instance. Also can receive the annotations of the text.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setBaseProperties({required String createdTime, required String lastEditedTime}) → void
Set the createdTime and the lastEditedTime properties.
inherited
toJson() → Map<String, dynamic>
Convert this to a valid json representation for the Notion API.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited