MultiSelectProp class

A representation of the multi select Notion object.

Inheritance

Constructors

MultiSelectProp({List<MultiSelectOption> options = const <MultiSelectOption>[]})
Main multi select constructor.
MultiSelectProp.fromJson(Map<String, dynamic> json, {String? subfield})

Properties

hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
The property id.
getter/setter pairinherited
isMultiSelect → bool
Returns true if property is MultiSelect type.
no setterinherited
isNone → bool
Returns true if property don't have a known type.
no setterinherited
isRichText → bool
Returns true if property is RichText type.
no setterinherited
isTitle → bool
Returns true if property is Title type.
no setterinherited
options ↔ List<MultiSelectOption>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
strType → String
The string value for this property type.
no setterinherited
type → PropertiesTypes
The property type. Always MultiSelect for this.
final
value → List<MultiSelectOption>
The options of the multi select.
no setteroverride

Methods

addOption(MultiSelectOption option) → MultiSelectProp
Add a new option to the multi select options and returns this instance.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert this to a valid json representation for the Notion API.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

contentIsList(Map<String, dynamic> json) → bool
Returns true if a json field is a list.
override