Text class

A representation of the Rich Text Notion.

Constructors

Text(String text, {TextAnnotations? annotations, Uri? url})
Main text constructor.
Text.fromJson(Map<String, dynamic> json)
Create a new Text instance from json.

Properties

annotations ↔ TextAnnotations?
The annotations of the text.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text ↔ String
The text intself.
getter/setter pair
url ↔ Uri?
The url of the text when the text is a link.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({String textSeparator = ''}) → Map<String, dynamic>
Convert this to a json representation valid for the Notion API.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromListJson(List json) → List<Text>
Map a list of texts from a json list with dynamics.