utils/utils library

Constants

all_str_property_types → const List<String>
The string values of all properties types.
blocks → const List<BlockTypes>
colors → const List<ColorsTypes>
objects → const List<ObjectTypes>
properties → const List<PropertiesTypes>

Properties

headingsTypes → List<BlockTypes>
The heading types.
no setter

Functions

blockTypeToString(BlockTypes type) → String
Returns the string value of the given block type.
colorTypeToString(ColorsTypes color) → String
Returns the string value of the given color type.
extractPropertyType(Map<String, dynamic> json) → PropertiesTypes
Extract the property type of a json property.
fieldIsList(dynamic field) → bool
Find if a json field is a List
objectTypeToString(ObjectTypes type) → String
Returns the string value of the given object type.
parentTypeToString(ParentType type) → String
Returns the string value of the given parent type.
propertyTypeToString(PropertiesTypes type) → String
Returns the string value of the given property type.
stringToBlockType(String type) → BlockTypes
Returns the block type of the given block type string.
stringToColorType(String color) → ColorsTypes
Returns the color type of the given color type string.
stringToObjectType(String type) → ObjectTypes
Returns the object type of the given object type string.
stringToParentType(String type) → ParentType
Returns the parent type of the given parent type string.
stringToPropertyType(String type) → PropertiesTypes
Returns the property type of the given property type string.